@@ -5,7 +5,7 @@
  * This file defines Turba's external API interface. Other applications can
  * interact with Turba through this API.
  *
- * Copyright 2009-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2009-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you did
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -205,38 +205,30 @@ class Turba_Api extends Horde_Registry_Api
              * book sources that are shared among all users.  Per-user shares
              * are shown in a folder for each respective user. */
             $owners = array(
-                'global' => true
+                'global' => _("Global Address Books")
             );
 
             foreach (Turba::listShares() as $share) {
-                $owners[$share->get('owner') ? $share->get('owner') : '-system-'] = true;
+                $owners[$share->get('owner') ? $registry->convertUsername($share->get('owner'), false) : '-system-'] = $share->get('owner') ?: '-system-';
             }
 
             $now = time();
 
-            foreach (array_keys($owners) as $owner) {
+            foreach ($owners as $externalOwner => $internalOwner) {
                 if (in_array('name', $properties)) {
-                    $results['turba/' . $owner]['name'] = $owner;
+                    $results['turba/' . $externalOwner]['name'] = $injector
+                        ->getInstance('Horde_Core_Factory_Identity')
+                        ->create($internalOwner)
+                        ->getName();
                 }
                 if (in_array('icon', $properties)) {
-                    $results['turba/' . $owner]['icon'] = Horde_Themes::img('turba.png');
+                    $results['turba/' . $externalOwner]['icon'] = Horde_Themes::img('turba.png');
                 }
                 if (in_array('browseable', $properties)) {
-                    $results['turba/' . $owner]['browseable'] = true;
+                    $results['turba/' . $externalOwner]['browseable'] = true;
                 }
-                if (in_array('contenttype', $properties)) {
-                    $results['turba/' . $owner]['contenttype'] = 'httpd/unix-directory';
-                }
-                if (in_array('contentlength', $properties)) {
-                    $results['turba/' . $owner]['contentlength'] = 0;
-                }
-                if (in_array('modified', $properties)) {
-                    // @TODO: Get a real modification date
-                    $results['turba/' . $owner]['modified'] = $now;
-                }
-                if (in_array('created', $properties)) {
-                    // @TODO Get a real creation date
-                    $results['turba/' . $owner]['created'] = 0;
+                if (in_array('read-only', $properties)) {
+                    $results['turba/' . $externalOwner]['read-only'] = true;
                 }
             }
 
@@ -273,24 +265,29 @@ class Turba_Api extends Horde_Registry_Api
                     ->listShares(
                         $registry->getAuth(),
                         array(
-                            'attributes' => $parts[0],
+                            'attributes' => $registry->convertUsername($parts[0], true),
                             'perm' => Horde_Perms::READ
                         )
                     );
             }
 
-            $curpath = 'turba/' . $parts[0] . '/';
-            $now = time();
+            $curpath = 'turba/' . $registry->convertUsername($parts[0], true) . '/';
 
             foreach ($addressbooks as $addressbook => $info) {
+                $label = ($info instanceof Horde_Share_Object)
+                    ? $info->get('name')
+                    : $info['title'];
                 if (in_array('name', $properties)) {
                     $results[$curpath . $addressbook]['name'] =
-                        sprintf(
-                            _("Contacts from %s"),
-                            ($info instanceof Horde_Share_Object)
-                                ? $info->get('name')
-                                : $info['title']
-                        );
+                        sprintf(_("Contacts from %s"), $label);
+                }
+                if (in_array('displayname', $properties)) {
+                    $results[$curpath . $addressbook]['displayname'] = $label;
+                }
+                if (in_array('owner', $properties)) {
+                    $results[$curpath . $addressbook]['owner'] = ($info instanceof Horde_Share_Object)
+                        ? $registry->convertUsername($info->get('owner'), false)
+                        : '-system-';
                 }
                 if (in_array('icon', $properties)) {
                     $results[$curpath . $addressbook]['icon'] = Horde_Themes::img('turba.png');
@@ -298,19 +295,9 @@ class Turba_Api extends Horde_Registry_Api
                 if (in_array('browseable', $properties)) {
                     $results[$curpath . $addressbook]['browseable'] = true;
                 }
-                if (in_array('contenttype', $properties)) {
-                    $results[$curpath . $addressbook]['contenttype'] = 'httpd/unix-directory';
-                }
-                if (in_array('contentlength', $properties)) {
-                    $results[$curpath . $addressbook]['contentlength'] = 0;
-                }
-                if (in_array('modified', $properties)) {
-                    // @TODO: Get a real modification date
-                    $results[$curpath . $addressbook]['modified'] = $now;
-                }
-                if (in_array('created', $properties)) {
-                    // @TODO Get a real creation date
-                    $results[$curpath . $addressbook]['created'] = 0;
+                if (in_array('read-only', $properties) &&
+                    ($info instanceof Horde_Share_Object)) {
+                    $results[$curpath . $addressbook]['read-only'] = !$info->hasPermission($registry->getAuth(), Horde_Perms::EDIT);
                 }
             }
 
@@ -332,35 +319,36 @@ class Turba_Api extends Horde_Registry_Api
                 return array();
             }
 
-            $contacts = $injector->getInstance('Turba_Factory_Driver')->create($parts[1])->search(array());
+            $addressbook = $injector->getInstance('Turba_Factory_Driver')
+                ->create($parts[1]);
+            $owner = $registry->convertUsername($addressbook->getContactOwner(), false);
+            $contacts = $addressbook->search(array());
             $contacts->reset();
 
-            $curpath = 'turba/' . $parts[0] . '/' . $parts[1] . '/';
+            $curpath = 'turba/' . $registry->convertUsername($parts[0], false) . '/' . $parts[1] . '/';
 
             while ($contact = $contacts->next()) {
                 $key = $curpath . $contact->getValue('__key');
                 if (in_array('name', $properties)) {
                     $results[$key]['name'] = Turba::formatName($contact);
                 }
+                if (in_array('owner', $properties)) {
+                    $results[$key]['owner'] = $owner;
+                }
                 if (in_array('icon', $properties)) {
                     $results[$key]['icon'] = Horde_Themes::img('mime/vcard.png');
                 }
                 if (in_array('browseable', $properties)) {
                     $results[$key]['browseable'] = false;
                 }
+                if (in_array('read-only', $properties)) {
+                    $results[$key]['read-only'] = !$addressbook->hasPermission(Horde_Perms::EDIT);
+                }
                 if (in_array('contenttype', $properties)) {
                     $results[$key]['contenttype'] = 'text/x-vcard';
                 }
-                if (in_array('contentlength', $properties)) {
-                    try {
-                        $data = $this->export($contact->getValue('__uid'), 'text/x-vcard', $contact->getSource(), null, array('skip_empty' => true));
-                    } catch (Turba_Exception $e) {
-                        $data = '';
-                    }
-                    $results[$key]['contentlength'] = strlen($data);
-                }
                 if (in_array('modified', $properties)) {
-                    $results[$key]['modified'] = $this->_modified($contact->getValue('__uid'), $parts[1]);
+                    $results[$key]['modified'] = $contact->lastModification() ?: null;
                 }
                 if (in_array('created', $properties)) {
                     $results[$key]['created'] = $this->getActionTimestamp($contact->getValue('__uid'), 'add', $parts[1]);
@@ -384,7 +372,7 @@ class Turba_Api extends Horde_Registry_Api
             $contact = $driver->getObject($parts[2]);
 
             $result = array(
-                'data' => $this->export($contact->getValue('__uid'), 'text/x-vcard', $contact->getSource(), null, array('skip_empty' => true)),
+                'data' => $driver->tovCard($contact, '2.1', null, true)->exportVcalendar(),
                 'mimetype' => 'text/x-vcard'
             );
             $modified = $this->_modified($contact->getValue('__uid'), $parts[1]);
@@ -1160,6 +1148,9 @@ class Turba_Api extends Horde_Registry_Api
                 continue;
             }
 
+            if (empty($opts['fields'][$source])) {
+                $opts['fields'][$source] = $GLOBALS['cfgSources'][$source]['search'];
+            }
             $sdriver = $driver->create($source);
 
             foreach ($names as $name) {
@@ -1173,9 +1164,6 @@ class Turba_Api extends Horde_Registry_Api
                             $criteria[$field] = $trimname;
                         }
                     }
-                    if (!count($criteria)) {
-                        $criteria['name'] = $trimname;
-                    }
                 }
 
                 try {
