@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you did
  * did not receive this file, see http://www.horde.org/licenses/apache.
  *
  * @category  Horde
- * @copyright 2010-2014 Horde LLC
+ * @copyright 2010-2015 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Turba
  */
@@ -19,7 +19,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org?
  * @category  Horde
- * @copyright 2010-2014 Horde LLC
+ * @copyright 2010-2015 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Turba
  */
@@ -57,7 +57,7 @@ class Turba_Application extends Horde_Registry_Application
 
     /**
      */
-    public $version = 'H5 (4.2.2)';
+    public $version = 'H5 (4.2.8)';
 
     /**
      */
@@ -85,17 +85,19 @@ class Turba_Application extends Horde_Registry_Application
      */
     protected function _init()
     {
-        global $injector, $registry, $session;
+        global $conf, $injector, $registry, $session;
 
-        /* For now, autoloading the Content_* classes depend on there being a
-         * registry entry for the 'content' application that contains at least
-         * the fileroot entry. */
-        $injector->getInstance('Horde_Autoloader')
-            ->addClassPathMapper(
-                new Horde_Autoloader_ClassPathMapper_Prefix('/^Content_/', $registry->get('fileroot', 'content') . '/lib/'));
+        if ($conf['tags']['enabled']) {
+            /* For now, autoloading the Content_* classes depend on there being
+             * a registry entry for the 'content' application that contains at
+             * least the fileroot entry. */
+            $injector->getInstance('Horde_Autoloader')
+                ->addClassPathMapper(
+                    new Horde_Autoloader_ClassPathMapper_Prefix('/^Content_/', $registry->get('fileroot', 'content') . '/lib/'));
 
-        if (!class_exists('Content_Tagger')) {
-            throw new Horde_Exception(_("The Content_Tagger class could not be found. Make sure the Content application is installed."));
+            if (!class_exists('Content_Tagger')) {
+                throw new Horde_Exception(_("The Content_Tagger class could not be found. Make sure the Content application is installed."));
+            }
         }
 
         // Turba source and attribute configuration.
@@ -218,8 +220,8 @@ class Turba_Application extends Horde_Registry_Application
         }
 
         $user = $GLOBALS['registry']->getAuth();
-        $url = Horde::url('');
         $edit = Horde::url('addressbooks/edit.php');
+        $url = Horde::url('');
 
         $sidebar->containers['my'] = array(
             'header' => array(
@@ -229,26 +231,22 @@ class Turba_Application extends Horde_Registry_Application
             ),
         );
         if ($GLOBALS['registry']->getAuth() &&
-            $GLOBALS['session']->get('turba', 'has_share')) {
+            $GLOBALS['session']->get('turba', 'has_share') &&
+            !empty($GLOBALS['conf']['shares']['source'])) {
+            $create = true;
             $sidebar->containers['my']['header']['add'] = array(
                 'url' => Horde::url('addressbooks/create.php'),
                 'label' => _("Create a new Address Book"),
             );
         }
-        $sidebar->containers['shared'] = array(
-            'header' => array(
-                'id' => 'turba-toggle-shared',
-                'label' => _("Shared Address Books"),
-                'collapsed' => true,
-            ),
-        );
         $shares = array();
-        foreach (Turba::listShares() as $id => $abook) {
+        $shared = array();
+        foreach (Turba::listShares(false, Horde_Perms::SHOW) as $id => $abook) {
             $row = array(
                 'selected' => $id == Turba::$source,
-                'url' => $url->add('source', $id),
+                'url' => $url->copy()->add('source', $id),
                 'label' => $abook->get('name'),
-                'edit' => $edit->add('a', $abook->getName()),
+                'edit' => $edit->copy()->add('a', $abook->getName()),
                 'type' => 'radiobox',
             );
             if ($abook->get('owner') && $abook->get('owner') == $user) {
@@ -260,12 +258,25 @@ class Turba_Application extends Horde_Registry_Application
                 if ($abook->get('owner')) {
                     $row['label'] .= ' [' . $GLOBALS['registry']->convertUsername($abook->get('owner'), false) . ']';
                 }
+                $shared[] = $row;
+            }
+            $shares[$id] = true;
+        }
+
+        if (!empty($create) || count($shared)) {
+            $sidebar->containers['shared'] = array(
+                'header' => array(
+                    'id' => 'turba-toggle-shared',
+                    'label' => _("Shared Address Books"),
+                    'collapsed' => true,
+                ),
+            );
+            foreach ($shared as $row) {
                 $sidebar->addRow($row, 'shared');
                 if ($row['selected']) {
                     $sidebar->containers['shared']['header']['collapsed'] = false;
                 }
             }
-            $shares[$id] = true;
         }
 
         $sidebar->containers['other'] = array(
@@ -275,13 +286,13 @@ class Turba_Application extends Horde_Registry_Application
                 'collapsed' => true,
             ),
         );
-        foreach (Turba::getAddressBooks(Horde_Perms::READ) as $id => $abook) {
+        foreach (Turba::getAddressBooks(Horde_Perms::SHOW) as $id => $abook) {
             if (isset($shares[$id])) {
                 continue;
             }
             $row = array(
                 'selected' => $id == Turba::$source,
-                'url' => $url->add('source', $id),
+                'url' => $url->copy()->add('source', $id),
                 'label' => $abook['title'],
                 'type' => 'radiobox',
             );
@@ -335,13 +346,13 @@ class Turba_Application extends Horde_Registry_Application
     {
         /* We need a clean copy of the $cfgSources array here.*/
         $cfgSources = Turba::availableSources();
-        foreach ($cfgSources as $source) {
+        foreach ($cfgSources as $sourceId => $source) {
             if (empty($source['use_shares'])) {
                 // Shares not enabled for this source
                 try {
                     $driver = $GLOBALS['injector']
                         ->getInstance('Turba_Factory_Driver')
-                        ->create($source);
+                        ->create($source, $sourceId);
                 } catch (Turba_Exception $e) {
                     Horde::log($e, 'ERR');
                 }
@@ -373,7 +384,7 @@ class Turba_Application extends Horde_Registry_Application
             try {
                 $driver = $GLOBALS['injector']
                     ->getInstance('Turba_Factory_Driver')
-                    ->create($config);
+                    ->create($config, $share->getName());
             } catch (Turba_Exception $e) {
                 continue;
             }
@@ -676,27 +687,41 @@ class Turba_Application extends Horde_Registry_Application
     {
         global $injector, $registry;
 
+        $hordeUser = $registry->convertUsername($user, true);
         $dav = $injector->getInstance('Horde_Dav_Storage');
         $factory = $injector->getInstance('Turba_Shares');
         $books = array();
         foreach (Turba::getAddressBooks(Horde_Perms::SHOW) as $id => $book) {
+            $readOnly = false;
+            switch ($book['type']) {
             // Ugly hack! There is currently no clean way to retrieve address
             // books that the user "owns", or to find out if a SQL/LDAP/Kolab
             // address book contains per-user or global contacts.
-            if ($book['type'] == 'share') {
+            case 'share':
                 $share = $factory->getShare($id);
                 if (($user == '-system-' && strlen($share->get('owner'))) ||
                     ($user != '-system-' &&
-                     $user != $share->get('owner') &&
-                     $user != $registry->getAuth())) {
+                     $hordeUser != $share->get('owner') &&
+                     $hordeUser != $registry->getAuth())) {
                     continue;
                 }
-            }
-            if ($user == '-system-' &&
-                ($book['type'] == 'facebook' ||
-                 $book['type'] == 'favourites' ||
-                 $book['type'] == 'vbook')) {
-                continue;
+                $readOnly = !$share->hasPermission($hordeUser, Horde_Perms::EDIT);
+                break;
+
+            case 'facebook':
+            case 'favourites':
+            case 'vbook':
+                if ($user == '-system-') {
+                    continue;
+                }
+                $readOnly = true;
+                break;
+
+            default:
+                if (!Turba::permissionsFilter(array($id => $book), Horde_Perms::EDIT)) {
+                    $readOnly = true;
+                }
+                break;
             }
             try {
                 $id = $dav->getExternalCollectionId($id, 'contacts') ?: $id;
@@ -724,6 +749,7 @@ class Turba_Application extends Horde_Registry_Application
                             ),
                         )
                     ),
+                '{http://sabredav.org/ns}read-only' => $readOnly
             );
         }
         return $books;
