@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2000-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2000-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you did
  * did not receive this file, see http://www.horde.org/licenses/apache.
  *
  * @category  Horde
- * @copyright 2000-2014 Horde LLC
+ * @copyright 2000-2015 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Turba
  */
@@ -17,7 +17,7 @@
  * @author    Chuck Hagenbuch <chuck@horde.org>
  * @author    Jon Parise <jon@horde.org>
  * @category  Horde
- * @copyright 2000-2014 Horde LLC
+ * @copyright 2000-2015 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Turba
  */
@@ -431,7 +431,7 @@ class Turba
 
         foreach ($in as $sourceId => $source) {
             try {
-                $driver = $factory->create($source);
+                $driver = $factory->create($source, $sourceId);
                 if ($driver->hasPermission($permission) &&
                     (empty($options['require_add']) || $driver->canAdd())) {
                     $out[$sourceId] = $source;
@@ -597,11 +597,11 @@ class Turba
     /**
      * Retrieve a new source config entry based on a Turba share.
      *
-     * @param Horde_Share object  The share to base config on.
+     * @param Horde_Share_Object object  The share to base config on.
      *
      * @return array  The $cfgSource entry for this share source.
      */
-    static public function getSourceFromShare(Horde_Share $share)
+    public static function getSourceFromShare(Horde_Share_Object $share)
     {
         // Require a fresh config file.
         $cfgSources = self::availableSources();
